@@ -11,7 +11,7 @@ from datetime import datetime
 
 
 import xgboost as xgb
-from sklearn.model_selection import train_test_split, StratifiedKFold
+from sklearn.model_selection import train_test_split, StratifiedKFold, cross_val_score
 from hyperopt import tpe, STATUS_OK, Trials, hp, fmin, space_eval
 from sklearn import metrics
 
@@ -298,7 +298,7 @@ class xgb_training:
         self.log.info(f"Recall at default threshold (test): {recall[1]}")
 
         self.model_artefacts[self.model_name]['fscore'] = fscore[1]
-        self.log.info(f"F_score at default threshold (test): {recall[1]}")
+        self.log.info(f"F_score at default threshold (test): {fscore[1]}")
         
         # precison, recall for the recall_precison curve
         self.precision_curve, self.recall_curve, _ = metrics.precision_recall_curve(self.y_test, self.pred_prob)
